==> react-form-pta-1.12.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { paramsToQueryString } from './querystring';
import { transformEventsListenersIntoCallbackMap } from './transformEventListeners';
var BASE_CLASS = 'sui-FormPta';
var CONTENT_CLASS = BASE_CLASS + "-content";
var IFRAME_ID = BASE_CLASS + "-iframe";
var SUBMIT_SUCCESS_EVENT_TYPE = 'SUBMIT_FORM_SUCCEEDED';
var SUBMIT_ERROR_EVENT_TYPE = 'SUBMIT_FORM_FAILED';
var MESSAGE_EVENT_TYPE = 'message';
var RESIZE_EVENT_TYPE = 'resize';
var DEFAULT_IFRAME_HEIGHT = 768;

var FormPta =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(FormPta, _Component);

  function FormPta(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    var _this$props = _this.props,
        BASE_URL = _this$props.formUrl,
        onSubmit = _this$props.onSubmit,
        onError = _this$props.onError,
        eventListeners = _this$props.eventListeners,
        settings = _objectWithoutPropertiesLoose(_this$props, ["formUrl", "onSubmit", "onError", "eventListeners"]);

    var QUERY = paramsToQueryString(settings);
    var formUrl = BASE_URL + "?" + QUERY;
    _this.runEventCallbacks = _this.runEventCallbacks.bind(_assertThisInitialized(_this));
    _this.state = {
      formUrl: formUrl
    };
    return _this;
  }

  var _proto = FormPta.prototype;

  _proto.componentDidMount = function componentDidMount() {
    // eslint-disable-line
    window.addEventListener(MESSAGE_EVENT_TYPE, this.runEventCallbacks);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    window.removeEventListener(MESSAGE_EVENT_TYPE, this.runEventCallbacks);
  };

  _proto.runEventCallbacks = function runEventCallbacks(_ref) {
    var _extends2, _ref2, _ref3;

    var _ref$data = _ref.data,
        type = _ref$data.type,
        payload = _ref$data.payload;
    var _this$props2 = this.props,
        onSubmit = _this$props2.onSubmit,
        onError = _this$props2.onError,
        eventListeners = _this$props2.eventListeners;
    var genericCallbackMap = eventListeners ? transformEventsListenersIntoCallbackMap(eventListeners) : [];

    var callbackMap = _extends((_extends2 = {}, _extends2[RESIZE_EVENT_TYPE] = [this.doResize], _extends2), onSubmit ? (_ref2 = {}, _ref2[SUBMIT_SUCCESS_EVENT_TYPE] = [onSubmit], _ref2) : {}, {}, onError ? (_ref3 = {}, _ref3[SUBMIT_ERROR_EVENT_TYPE] = [onError], _ref3) : {}, {}, genericCallbackMap);

    var currentMessageCallbacks = callbackMap[type] || [];
    currentMessageCallbacks.map(function (callback) {
      return callback(payload);
    });
  };

  _proto.doResize = function doResize(height) {
    if (height === void 0) {
      height = DEFAULT_IFRAME_HEIGHT;
    }

    var ptaIframe = document.getElementById(IFRAME_ID);
    ptaIframe.style.height = height + "px";
  }
  /**
   * Avoid iframe re-rendering
   */
  ;

  _proto.shouldComponentUpdate = function shouldComponentUpdate() {
    return false;
  };

  _proto.render = function render() {
    var _this2 = this;

    var formUrl = this.state.formUrl;
    return React.createElement("div", {
      className: BASE_CLASS
    }, React.createElement("iframe", {
      id: IFRAME_ID,
      ref: function ref(_ref4) {
        return _this2._iframeRef = _ref4;
      },
      className: CONTENT_CLASS,
      src: formUrl
    }));
  };

  return FormPta;
}(Component);

FormPta.displayName = 'FormPta';
FormPta.defaultProps = {
  enableDraft: false
};
export default FormPta;

==> react-form-pta-1.13.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { paramsToQueryString } from './querystring';
import { transformEventsListenersIntoCallbackMap } from './transformEventListeners';
var BASE_CLASS = 'sui-FormPta';
var CONTENT_CLASS = BASE_CLASS + "-content";
var IFRAME_ID = BASE_CLASS + "-iframe";
var SUBMIT_SUCCESS_EVENT_TYPE = 'SUBMIT_FORM_SUCCEEDED';
var SUBMIT_ERROR_EVENT_TYPE = 'SUBMIT_FORM_FAILED';
var MESSAGE_EVENT_TYPE = 'message';
var RESIZE_EVENT_TYPE = 'resize';
var DEFAULT_IFRAME_HEIGHT = 768;

var FormPta = /*#__PURE__*/function (_Component) {
  _inheritsLoose(FormPta, _Component);

  function FormPta(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    var _this$props = _this.props,
        BASE_URL = _this$props.formUrl,
        onSubmit = _this$props.onSubmit,
        onError = _this$props.onError,
        eventListeners = _this$props.eventListeners,
        settings = _objectWithoutPropertiesLoose(_this$props, ["formUrl", "onSubmit", "onError", "eventListeners"]);

    var QUERY = paramsToQueryString(settings);
    var formUrl = BASE_URL + "?" + QUERY;
    _this.runEventCallbacks = _this.runEventCallbacks.bind(_assertThisInitialized(_this));
    _this.state = {
      formUrl: formUrl
    };
    return _this;
  }

  var _proto = FormPta.prototype;

  _proto.componentDidMount = function componentDidMount() {
    // eslint-disable-line
    window.addEventListener(MESSAGE_EVENT_TYPE, this.runEventCallbacks);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    window.removeEventListener(MESSAGE_EVENT_TYPE, this.runEventCallbacks);
  };

  _proto.runEventCallbacks = function runEventCallbacks(_ref) {
    var _extends2, _ref2, _ref3;

    var _ref$data = _ref.data,
        type = _ref$data.type,
        payload = _ref$data.payload;
    var _this$props2 = this.props,
        onSubmit = _this$props2.onSubmit,
        onError = _this$props2.onError,
        eventListeners = _this$props2.eventListeners;
    var genericCallbackMap = eventListeners ? transformEventsListenersIntoCallbackMap(eventListeners) : [];

    var callbackMap = _extends((_extends2 = {}, _extends2[RESIZE_EVENT_TYPE] = [this.doResize], _extends2), onSubmit ? (_ref2 = {}, _ref2[SUBMIT_SUCCESS_EVENT_TYPE] = [onSubmit], _ref2) : {}, {}, onError ? (_ref3 = {}, _ref3[SUBMIT_ERROR_EVENT_TYPE] = [onError], _ref3) : {}, {}, genericCallbackMap);

    var currentMessageCallbacks = callbackMap[type] || [];
    currentMessageCallbacks.map(function (callback) {
      return callback(payload);
    });
  };

  _proto.doResize = function doResize(height) {
    if (height === void 0) {
      height = DEFAULT_IFRAME_HEIGHT;
    }

    var ptaIframe = document.getElementById(IFRAME_ID);
    ptaIframe.style.height = height + "px";
  }
  /**
   * Avoid iframe re-rendering
   */
  ;

  _proto.shouldComponentUpdate = function shouldComponentUpdate() {
    return false;
  };

  _proto.render = function render() {
    var _this2 = this;

    var formUrl = this.state.formUrl;
    return React.createElement("div", {
      className: BASE_CLASS
    }, React.createElement("iframe", {
      id: IFRAME_ID,
      ref: function ref(_ref4) {
        return _this2._iframeRef = _ref4;
      },
      className: CONTENT_CLASS,
      src: formUrl
    }));
  };

  return FormPta;
}(Component);

FormPta.displayName = 'FormPta';
FormPta.defaultProps = {
  enableDraft: false
};
export default FormPta;
